@@ -364,7 +364,18 @@ label_1:
             for(i=0; i<10;i++)
             if ((mouse_info.col > fkPos[i]) && (mouse_info.col < fkPos[i+1]))
             {  if (i==9)ink='0'; else ink='1'+i;}
-         } else if ( (mouse_info.col < col ) || (mouse_info.col >col+ncol+1) || (mouse_info.row < row ) || (mouse_info.row >row+height+1) )   goto label_3; 
+         } else if ( (mouse_info.col < col ) || (mouse_info.col >col+ncol+1) || (mouse_info.row < row ) || (mouse_info.row >row+height+1) ) 
+         {   int col=mouse_info.col;
+             int row=mouse_info.row;
+             usleep(200000);
+             if(crt0_keypressed())
+             { 
+                 if(inkey()==KB_MOUSE &&  mouse_info.row==row && mouse_info.col==col)
+                 {  clearTypeAhead();
+                    goto label_3;
+                 }
+             }    
+         } 
          else  
          {  mousePos = mouse_info.row - row;
             if (mousePos==0)
