@@ -26,10 +26,6 @@ extern double *BWrange_int;
 extern REAL *va_int;
 extern char*hiddenf;
 
-extern double SQMEUSR(int nsub,double GG,REAL*momenta,REAL*cb_coeff,int * err);
-extern const  int SQMEUSRFLAG;
-
-
 extern colorBasis * cb_int;
 extern REAL * cb_coeff_int;
 
