@@ -50,10 +50,10 @@ int eqvect_(char *lv1, char *lv2)
 int spole_(char *lv)
 {
    int i1=0,i2=0,n,i=0;
-   
-   while(n=lv[i++]){ if(n>nin_int) i1++; else i2++;}  
-   if(i2==nin_int) i2=0;
-   return  ! (i1 && i2);
+   while((n=lv[i++])){ if(n>nin_int) i1++; else i2++;}  
+//   if(i2==nin_int) i2=0;
+   if(i1+i2==nin_int+nout_int) return 0;
+   return  (i1 && !i2)|| (!i1 && i2);
 } 
 
 
