@@ -27,6 +27,7 @@
 #include "spectrum.h"
 #include "num_in.h"
 #include "comp.h"
+#include "dynamic_cs.h"
 
 #include"../../include/version.h"
 
@@ -195,12 +196,10 @@ static void f7_prog(int mode)
              case 11: sprintf(title+strlen(title)," F(x=%.2E,Q)",x0);     break;
            }
            if(pos==11) xName="Q"; else xName="x";
-           if(on[0]&&on[1]) plot_N("Partice structure functions",xName,z1,z2, LOG,title, 2, 
-                              p_name[0], nPoints, f[0], NULL,
-                              p_name[1], nPoints, f[1], NULL);
+           if(on[0]&&on[1]) plot_N(title, xName, z1,z2,  LOG, 2, nPoints, f[0],NULL,p_name[0],nPoints,f[1],NULL,p_name[1]);
            else 
            { if(on[0]) l=0; else l=1;
-              plot_N("Particle structure function",xName, z1,z2, LOG,title,1,p_name[l], nPoints, f[l],NULL);   
+              plot_N(title,xName,z1,z2,  LOG,1, nPoints, f[l],NULL,p_name[l]);   
            }  
            put_text(&screen);
          } else messanykey(16,5," Correct input is \n"
@@ -332,12 +331,13 @@ L1:
       char strmen[] ="\030"
                       " BreitWigner range XXX  "
                       " T-channel widths   YYY "
-                      " GI in BreitWigner  ZZZ ";
+                      " GI in t-channel    TTT "
+                      " GI in s-channel    SSS ";   
 
       improveStr(strmen,"XXX","%.1f",*BWrange_int);
       improveStr(strmen,"YYY", (*twidth_int)? "ON" : "OFF");
-      improveStr(strmen,"ZZZ",(*gswidth_int)? "ON" : "OFF");
-
+      improveStr(strmen,"TTT",(*gtwidth_int)? "ON" : "OFF");
+      improveStr(strmen,"SSS",(*gswidth_int)? "ON" : "OFF");
       menu1(54,6,"",strmen,"n_width_*",&pscr ,&key);
    }
 
@@ -347,8 +347,9 @@ L1:
               if(*BWrange_int<0) *BWrange_int=-*BWrange_int;
               if(*BWrange_int>999.9) *BWrange_int=999.9;
               break;
-     case 2:  *twidth_int = ! *twidth_int; break;
-     case 3:  *gswidth_int =! *gswidth_int; break;
+     case 2:  *twidth_int = ! *twidth_int;  break;
+     case 3:  *gtwidth_int =! *gtwidth_int; break; 
+     case 4:  *gswidth_int =! *gswidth_int; break;
    }    
     goto L1;
 } /* w_men__ */
