@@ -2,19 +2,18 @@
 #define __PRE_READ_
 #include"sets.h"
 
-typedef setrec {abracadabra} typeindlist;    /* [1..9], used by Editor  */
 
 typedef struct preresrecord
    {
       struct preresrecord * next;
       int            free;
-      int            tp;
+      unsigned       tp;
       long           num;
       unsigned       maxp;      /*  How many pulses: used by Editor   */
       unsigned       degp;
       int            g5;
       unsigned       maxg;
-      typeindlist    indlist;
+      unsigned       indlist;
       int            nvar;
       unsigned *     varsdeg;
    }  preresrecord;
