@@ -52,13 +52,25 @@ static void errorMessage( char * fieldName, char * format, ...)
    vsprintf(dump,format,args);
    va_end(args);
 
-printf("dump=|%s|\n",dump);
+//printf("dump=|%s|\n",dump);
+
    if (strcmp(dump,"*") == 0)
-    sprintf(errorText,"Error in table '%s' line %d field '%s'\nposition %u: %s",
+   { if(rderrpos)
+          sprintf(errorText,"Error in table '%s' line %d field '%s'\nposition %u: %s",
 	  tabName,nLine,fieldName,rderrpos,errmesstxt(rderrcode) );
+     else sprintf(errorText,"Error in table '%s' line %d field '%s'\n %s",
+          tabName,nLine,fieldName,errmesstxt(rderrcode) );
+   }                   	  
    else
-    sprintf(errorText,"Error in table '%s' line %d field '%s'  position %u:\n  %s",
+   { 
+     if(rderrpos)
+           sprintf(errorText,"Error in table '%s' line %d field '%s'  position %u:\n  %s",
            tabName,nLine,fieldName, rderrpos, dump);
+     else 
+           sprintf(errorText,"Error in table '%s' line %d field '%s' \n  %s",
+           tabName,nLine,fieldName,  dump);
+   }
+                                
    if(blind==1) { printf("ERROR:%s\n",errorText); exit(125);} else messanykey(2,10,errorText);
 }
 
@@ -992,7 +1004,7 @@ static int  readlagrangian(int check, int ugForce)
          }
   }
 
-  if (check && lgrgn1)
+  if (check && lgrgn)
   {
     mLine=nLine;
     lgrgn1 = lgrgn;   /*    check1       */
